GoogleInterstitial class

Constructors

GoogleInterstitial()

Properties

hashCode int
The hash code for this object.
no setterinherited
interstitialAd ↔ InterstitialAd?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadAd({required BuildContext context, required dynamic onLoaded(), required dynamic onComplete(), required dynamic onFailed()}) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited