Ads class

Constructors

Ads()
factory

Properties

currentAdIndex int
getter/setter pair
failCounter int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
routeIndex Map
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timer Timer?
getter/setter pair

Methods

indexIncrement(String? key, int maxIndex) → void
loopBreaker(int maxRetry) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showActionBasedAds({required BuildContext context, required String actionName, required VoidCallback onComplete}) → void
showFullScreen({required BuildContext context, required VoidCallback onComplete}) → void
showScreenActionBasedAds({required BuildContext context, required String actionName, required VoidCallback onComplete}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited