margin property
Overrides the global MainJson.nativeMargin set via Adhub for this specific ad slot. Leave null to use the app-wide default.
Implementation
final EdgeInsets? margin;
Overrides the global MainJson.nativeMargin set via Adhub for this specific ad slot. Leave null to use the app-wide default.
final EdgeInsets? margin;