AdhubNotifications class

Constructors

AdhubNotifications()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isOptedIn bool
Returns whether the user is currently opted-in to receive push notifications.
no setter

Static Methods

disableNotifications() → void
Disables push notifications for the end user.
enableNotifications() → void
Enables push notifications for the end user.