AdhubDialogs class

Constructors

AdhubDialogs()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showMaintenanceDialog(BuildContext context, String message) → void
showMigrationDialog(BuildContext context, String url) → void
showNetworkErrorDialog(BuildContext context, VoidCallback retryFetch) → void
showRateUsDialog(MainJson mainJson) Future<void>
showSoftUpdateDialog(BuildContext context, String url, String remoteVersion, VoidCallback onProceed) → void
showUpdateDialog(BuildContext context, String url) → void